@@ -14,13 +14,9 @@ from .error_handling import (
     create_timeout_handler,
     handle_errors,
 )
-
-# MCP tool decorator
+from .hints import hints
 from .mcp_tool import mcp_tool
 from .performance import get_performance_summary, measure_performance
-
-# Note: physics_hints, query_hints, sample, and tool_hints are not imported here
-# to avoid circular dependencies. Import them directly when needed.
 from .tool_recommendations import generate_tool_recommendations, recommend_tools
 from .validation import create_validation_schema, validate_input
 
@@ -43,6 +39,7 @@ __all__ = [
     "create_timeout_handler",
     # MCP tool decorator
     "mcp_tool",
+    "hints",
     # Error classes
     "ToolError",
     "ValidationError",
