@@ -10,10 +10,12 @@ from typing import Any
 
 from fastmcp import Context
 
+from imas_mcp import dd_version
 from imas_mcp.graph_analyzer import IMASGraphAnalyzer
 from imas_mcp.models.error_models import ToolError
 from imas_mcp.models.request_models import AnalysisInput
 from imas_mcp.models.result_models import StructureResult
+from imas_mcp.resource_path_accessor import ResourcePathAccessor
 from imas_mcp.search.decorators import (
     cache_results,
     handle_errors,
@@ -50,13 +52,10 @@ class AnalysisTool(BaseTool):
     def _load_relationships_data(self):
         """Load relationships data for clustering-enhanced analysis."""
         try:
-            import importlib.resources
             import json
 
-            relationships_file = (
-                importlib.resources.files("imas_mcp.resources.schemas")
-                / "relationships.json"
-            )
+            path_accessor = ResourcePathAccessor(dd_version=dd_version)
+            relationships_file = path_accessor.schemas_dir / "relationships.json"
             with relationships_file.open("r", encoding="utf-8") as f:
                 self._relationships_data = json.load(f)
                 logger.info(
@@ -221,8 +220,35 @@ class AnalysisTool(BaseTool):
             # For no data case, we expect query to be the IDS name
             ids_name = tool_context.get("query", "")
             return self._build_no_data_prompt_simple(ids_name)
+        elif prompt_type == "structure_description_sampling":
+            return self._build_description_sampling_prompt(tool_context)
         return ""
 
+    def _build_description_sampling_prompt(self, context: dict[str, Any]) -> str:
+        """Build prompt for sampling structure description."""
+        ids_name = context.get("ids_name", "")
+        current_description = context.get("current_description", "")
+        sample_paths = context.get("sample_paths", [])
+        max_depth = context.get("max_depth", 0)
+
+        prompt = f"""Current description for '{ids_name}' IDS structure:
+{current_description}
+
+Structure metrics:
+- Max depth: {max_depth}
+- Sample paths: {", ".join(sample_paths[:5])}
+
+Sample and improve this description by:
+1. Adding physics context and measurement organization principles
+2. Explaining key structural patterns and data hierarchy
+3. Highlighting important branching points and identifier schemas
+4. Providing practical guidance for data access and navigation
+5. Connecting to common fusion physics workflows
+
+Focus on clarity and practical utility for researchers working with this IDS."""
+
+        return prompt
+
     def system_prompt(self) -> str:
         """Get enhanced analysis tool-specific system prompt."""
         return """You are an expert IMAS data architect and fusion physics analyst specializing in:
@@ -266,6 +292,37 @@ Provide analysis that helps researchers understand not just what data is availab
 with it effectively using both structural insights and visual navigation aids for their specific
 research contexts."""
 
+    def build_sample_tasks(self, tool_result) -> list[dict[str, Any]]:
+        """Build sampling tasks specific to StructureResult."""
+        from imas_mcp.models.result_models import StructureResult
+
+        tasks = super().build_sample_tasks(tool_result)  # Get base tasks
+
+        if isinstance(tool_result, StructureResult):
+            # Sample structure-specific description
+            if tool_result.description:
+                tasks.append(
+                    {
+                        "field": "description",
+                        "prompt_type": "structure_description_sampling",
+                        "context": {
+                            "ids_name": tool_result.ids_name,
+                            "current_description": tool_result.description,
+                            "sample_paths": tool_result.sample_paths[:5],
+                            "max_depth": tool_result.max_depth,
+                        },
+                    }
+                )
+
+        return tasks
+
+    def _apply_description_sampling(self, tool_result, sampled_content: str) -> None:
+        """Apply custom sampling for description field."""
+        from imas_mcp.models.result_models import StructureResult
+
+        if isinstance(tool_result, StructureResult):
+            tool_result.description = sampled_content
+
     def _build_structure_analysis_prompt(self, tool_context: dict[str, Any]) -> str:
         """Build prompt for IDS structure analysis with enhanced capabilities."""
         ids_name = tool_context.get("ids_name", "")
